@@ -133,7 +133,7 @@ def abi_register_name(register: int, abi: bool) -> str:
     if abi:
         abi_names = [
             'zero', 'ra', 'sp', 'gp', 'tp', 't0', 't1', 't2',
-            'fp/s0', 's1', 'a0', 'a1', 'a2', 'a3', 'a4', 'a5',
+            'fp', 's1', 'a0', 'a1', 'a2', 'a3', 'a4', 'a5',
             'a6', 'a7',  's2', 's3', 's4', 's5', 's6', 's7',
             's8', 's9', 's10', 's11', 't3', 't4', 't5', 't6'
         ]
